@@ -30,4 +30,16 @@ __all__ = ['config',
            'sound',
            'sprites',
            'states',
+           'timer',
+           'ui',
            'vector',]
+__docformat__ = 'reStructuredText'
+
+import config
+import joystick
+import sound
+import sprites
+import states
+import timer
+import ui
+import vector
